@@ -45,8 +45,8 @@ Q_GLOBAL_STATIC(QString, _themeOverride)
 // For this reason we use AppDataLocation: BINDIR/data on Windows, Resources on OS X
 void initRCCIconTheme()
 {
-#ifdef WITH_BREEZEICONS
-    BreezeIcons::initIcons()
+#ifdef WITH_BREEZEICONS_LIB
+    BreezeIcons::initIcons();
 #else
     const QString iconThemeRcc = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("icontheme.rcc"));
     if (!iconThemeRcc.isEmpty()) {
